@@ -3,12 +3,12 @@
 import logging
 import csv
 import os
-from .models import KEGGPathway
-from .storage import KEGGDataStorage
-from .resolver import KEGGPathwayResolver
-from typing import List, Any, Dict, NoReturn, Optional, Union
+from typing import List, Any, Union
+from io import TextIOWrapper
 import scipy.stats as stats
-from io import TextIOWrapper, StringIO
+from .resolver import KEGGPathwayResolver
+# from .models import KEGGPathway
+# from .storage import KEGGDataStorage
 
 
 # def get_all_pathways(org: str):
@@ -23,7 +23,26 @@ from io import TextIOWrapper, StringIO
 
 
 class KEGGPathwayAnalysisResult:
-    def __init__(self, org: str, pathway_id: str, pathway_name: str, found_genes: list, pathway_genes: list):
+    """
+    Results of KEGG pathway enrichment analysis
+    """
+
+    # pylint: disable=too-many-instance-attributes,too-many-arguments
+    def __init__(self,
+                 org: str,
+                 pathway_id: str,
+                 pathway_name: str,
+                 found_genes: list,
+                 pathway_genes: list):
+
+        """
+        Init Result of KEGG pathway enrichment analysis
+        :param org: str
+        :param pathway_id: str
+        :param pathway_name: str
+        :param found_genes: list
+        :param pathway_genes: list
+        """
 
         self.organism: str = org
         self.pathway_id = pathway_id
@@ -32,7 +51,7 @@ class KEGGPathwayAnalysisResult:
         self.study_count = len(found_genes)
         self.pathway_genes = pathway_genes
         self.pathway_genes_count = len(pathway_genes)
-        self.pvalue : Union[float, None] = None
+        self.pvalue: Union[float, None] = None
 
         # self.args = {
         #     "organism": org,
@@ -45,19 +64,38 @@ class KEGGPathwayAnalysisResult:
         #     "pvalue": "",
         # }
 
+
     def __str__(self):
-        return f"<KEGGPathwayAnalysisResult {self.organism}:{self.pathway_id} ({pathway_name}) {self.found_genes}/{self.pathway_genes_count}>"
+        """
+        Build string summary
+        :return: str
+        """
+        return f"<KEGGPathwayAnalysisResult {self.organism}:{self.pathway_id}" \
+                f" ({self.pathway_name}) {len(self.found_genes)}/{self.pathway_genes_count}>"
 
 
     def __repr__(self):
-        print(self.__str__())
+        """
+        Print out string summary
+        """
+        return self.__str__()
+
 
     def set_pvalue(self, pval: float):
+        """
+        Set p value for enrichment analysis
+        :param pval: float
+        """
         # self.args["pvalue"] = pval
         self.pvalue = pval
 
 
     def json_summary(self, gene_delimiter=","):
+        """
+        Build json summary for enrichment analysis
+        :param gene_delimiter: str
+        :return: dict
+        """
 
         # result = list()
         # result.append(self.args["pathway_name"])
@@ -82,14 +120,34 @@ class KEGGPathwayAnalysisResult:
 
     @staticmethod
     def get_header():
+        """
+        Build default header for enrichment analysis
+        :return: list
+        """
+
         # return list(self.args.keys())
-        return ["pathway_name", "pathway_id", "study_count", "pathway_genes", "pvalue", "found_genes"]
+        return ["pathway_name",
+                "pathway_id",
+                "study_count",
+                "pathway_genes",
+                "pvalue",
+                "found_genes"]
 
 
 
 
 class KEGGPathwayAnalysis:
-    def __init__(self, org: str, pathways=None):
+    """
+    KEGG pathway enrichment analysis
+    """
+
+    def __init__(self, org: str, pathways: Any = None):
+        """
+        Init KEGG pathway enrichment analysis
+        :param org: str
+        :param pathways: Any
+        """
+
         self.organism = org
         self.summary: List[Any] = []
         self.resolver = KEGGPathwayResolver(self.organism)
@@ -97,15 +155,15 @@ class KEGGPathwayAnalysis:
         # self.all_pathways = get_all_pathways(org=self.organism)
         self.all_pathways = {}
 
-        if pathways == None:
+        if pathways is None:
             # If pathways are not set use all pathways
             self.all_pathways = self.resolver.get_pathway_list()
 
-        elif type(pathways) == dict:
+        elif isinstance(pathways, dict):
             # Use given data when dict is passed
             self.all_pathways = pathways
 
-        elif type(pathways) == list:
+        elif isinstance(pathways, list):
             # Load all pathways and filter for pathways in list
             for key, value in self.resolver.get_pathway_list().items():
                 if key in pathways:
@@ -119,7 +177,10 @@ class KEGGPathwayAnalysis:
 
 
     def _check_analysis_result_exist(self):
-        # Check if summary exists
+        """
+        Check if summary exists
+        :return: bool
+        """
         if not self.summary or len(self.summary) == 0:
             raise ValueError("need to 'run_summary' first")
 
@@ -140,8 +201,8 @@ class KEGGPathwayAnalysis:
 
         if inplace:
             self.summary = buffer
-        else:
-            return buffer
+
+        return buffer
 
 
     def run_analysis(self, gene_list: list):
@@ -150,6 +211,7 @@ class KEGGPathwayAnalysis:
         :param gene_list: list
         :return: list(KEGGPathwayAnalysisResult)
         """
+        # pylint: disable=too-many-locals
 
         result = []
         all_found_genes = 0
@@ -170,7 +232,11 @@ class KEGGPathwayAnalysis:
                     genes_found.append(gene_id)
 
             all_found_genes += len(genes_found)
-            pathway_result = KEGGPathwayAnalysisResult(org="mmu", pathway_id=pathway_id, pathway_name=name, found_genes=genes_found, pathway_genes=all_pathways_genes)
+            pathway_result = KEGGPathwayAnalysisResult(org="mmu",
+                                                       pathway_id=pathway_id,
+                                                       pathway_name=name,
+                                                       found_genes=genes_found,
+                                                       pathway_genes=all_pathways_genes)
             result.append(pathway_result)
 
         # Perform Fisher exact test
@@ -185,7 +251,8 @@ class KEGGPathwayAnalysis:
                 c_var = analysis.pathway_genes_count - analysis.study_count
                 d_var = absolute_pathway_genes - analysis.pathway_genes_count - b_var
 
-                # print(a_var, b_var, "\n", c_var, d_var, "\n" + str(absolute_pathway_genes) + "-" * 10)
+                # print(a_var, b_var, "\n", c_var, d_var,
+                # "\n" + str(absolute_pathway_genes) + "-" * 10)
 
                 _, pval = stats.fisher_exact(
                     [
@@ -202,7 +269,10 @@ class KEGGPathwayAnalysis:
 
                 analysis.set_pvalue(pval=pval)
             else:
-                logging.debug(f"No genes found for {analysis.organism}:{analysis.pathway_id}. p value calculation skipped.")
+                logging.debug("No genes found for %s:%s." \
+                              " p value calculation skipped.",
+                              analysis.organism,
+                              analysis.pathway_id)
 
         self.summary = result
         return result
@@ -217,8 +287,8 @@ class KEGGPathwayAnalysis:
     #     result = list()
     #     result.append("\t".join(KEGGPathwayAnalysisResult.get_header()))
 
-    #     # TODO export as file option
-    #     # TODO use csv dict writer
+    #     # export as file option
+    #     # use csv dict writer
 
     #     for item in self.summary:
     #         result.append(item.line_summary())
@@ -230,6 +300,8 @@ class KEGGPathwayAnalysis:
         Return analysis result as pandas DataFrame
         """
         try:
+            # Ignore import lint at this place to keep pandas an optional dependency
+            # pylint: disable=import-outside-toplevel
             import pandas
 
             # Check if summary exists
@@ -239,12 +311,18 @@ class KEGGPathwayAnalysis:
                 summary_list.append(result.json_summary())
             return pandas.DataFrame(summary_list)
         except ImportError:
-            # print("Package 'pandas' is not installed. To use this function please 'pip install pandas'")
-            logging.error("Package 'pandas' is not installed. To use this function please 'pip install pandas'")
+            logging.error("Package 'pandas' is not installed." \
+                          "To use this function please 'pip install pandas'")
             return None
 
 
     def fexport(self, file: Union[str, TextIOWrapper], delimiter="\t", overwrite=False):
+        """
+        Save result summary as file
+        :param file: Union[str, TextIOWrapper]
+        :param delimiter: str
+        :param overwrite: bool
+        """
 
         # Check if summary exists
         self._check_analysis_result_exist()
@@ -252,7 +330,8 @@ class KEGGPathwayAnalysis:
         if isinstance(file, str):
             # file is str (Name of file)
             if os.path.isfile(file) and not overwrite:
-                raise RuntimeError(f"File {file} does already exist. To solve please set overwrite=True.")
+                raise RuntimeError(f"File {file} does already exist." \
+                                    "To solve please set overwrite=True.")
 
             csv_file = open(file, mode="w", encoding="utf-8")
         elif isinstance(file, TextIOWrapper):
@@ -279,4 +358,3 @@ class KEGGPathwayAnalysis:
 
 if __name__ == "__main__":
     pass
-
