@@ -5,7 +5,7 @@ import os
 import re
 import pickle
 
-from .utils import parse_tsv, request as request_url, getcwd
+from .utils import parse_tsv, request as request_url
 from .const import KEGG_DATA
 
 
@@ -16,19 +16,38 @@ class KEGGDataStorage:
     """
     @staticmethod
     def _check_env():
+        """
+        Check if caching environment is set up
+        :return: bool
+        """
+
         # Check if folder exists
         cache_dir = KEGG_DATA
         if not os.path.isdir(cache_dir):
-            logging.debug(f"Cache directory does not exist. Creating directory {cache_dir}")
+            logging.debug("Cache directory does not exist. Creating directory %s", cache_dir)
             os.mkdir(cache_dir)
 
+
     @staticmethod
     def build_path(filename: str):
+        """
+        Build absolute filename for caching dir
+        :param filename: str
+        :return: str
+        """
+
         KEGGDataStorage._check_env()
         return os.path.join(KEGG_DATA, filename)
 
+
     @staticmethod
     def exist(filename: str):
+        """
+        Check if filename exist in caching dir
+        :param filename: str
+        :return: bool
+        """
+
         KEGGDataStorage._check_env()
         return os.path.isfile(os.path.join(KEGG_DATA, filename))
 
@@ -50,12 +69,13 @@ class KEGGDataStorage:
                 if len(item) == 4 and item[0] != "":
                     organism_list[item[1]] = item[2]
             pickle.dump(organism_list, open(path, "wb"))
-            logging.debug("Request organism list and dump to {PATH}".format(PATH=path))
+            logging.debug("Request organism list and dump to %s", path)
         else:
             organism_list = pickle.load(open(path, "rb"))
-            logging.debug("Load organism list from {PATH}".format(PATH=path))
+            logging.debug("Load organism list from %s", path)
         return organism_list
 
+
     @staticmethod
     def get_organism_name(org_code: str):
         """
@@ -63,8 +83,10 @@ class KEGGDataStorage:
         :param org_code: str
         :return: str
         """
+
         return KEGGDataStorage.get_organism_list().get(org_code, None)
 
+
     @staticmethod
     def check_organism(org: str):
         """
@@ -72,24 +94,28 @@ class KEGGDataStorage:
         :param org: str
         :return: bool
         """
+
         organism_list = KEGGDataStorage.get_organism_list()
         return org in organism_list.keys()
 
+
     @staticmethod
     def list_existing_pathways():
         """
         List all KEGG pathway files saved in storage directory. [<filename>]
         :return: list
         """
+
         # <org>_path<code>.kgml
         found = []
         pattern = r"[a-z]{3}_path[0-9]{5}\.kgml"
         for item in os.listdir(KEGG_DATA):
             if re.match(pattern, item, re.IGNORECASE):
                 found.append(item)
-        logging.debug("Found {N} pathway files".format(N=len(found)))
+        logging.debug("Found %d pathway files", len(found))
         return found
 
+
     @staticmethod
     def pathway_file_to_id(pathway: str):
         """
@@ -97,9 +123,11 @@ class KEGGDataStorage:
         :param pathway: str
         :return: str
         """
+
         pattern = r"[a-z]{3}_path([0-9]{5})\.kgml"
         return re.findall(pattern, pathway, re.IGNORECASE)[0]
 
+
     @staticmethod
     def pathway_to_id(pathway: str):
         """
@@ -107,9 +135,11 @@ class KEGGDataStorage:
         :param pathway: str
         :return: str
         """
+
         pattern = r"path:[a-z]{3}([0-9]{5})"
         return re.findall(pattern, pathway, re.IGNORECASE)[0]
 
+
     @staticmethod
     def pathway_file_exist(org: str, code: str):
         """
@@ -118,7 +148,11 @@ class KEGGDataStorage:
         :param code: str
         :return: bool
         """
-        return os.path.isfile(os.path.join(KEGG_DATA, "{ORG}_path{CODE}.kgml".format(ORG=org, CODE=code)))
+
+        kgml_filename = os.path.join(KEGG_DATA, "{ORG}_path{CODE}.kgml".format(ORG=org,
+                                                                               CODE=code))
+        return os.path.isfile(kgml_filename)
+
 
     @staticmethod
     def pathway_list_exist(org: str):
@@ -127,8 +161,10 @@ class KEGGDataStorage:
         :param org: str
         :return bool
         """
+
         return os.path.isfile(os.path.join(KEGG_DATA, "pathway_{ORG}.dump".format(ORG=org)))
 
+
     @staticmethod
     def load_pathway(org: str, code: str):
         """
@@ -137,10 +173,13 @@ class KEGGDataStorage:
         :param code: str
         :return: str
         """
+
         if KEGGDataStorage.pathway_file_exist(org=org, code=code):
             return KEGGDataStorage.load("{ORG}_path{CODE}.kgml".format(ORG=org, CODE=code))
-        else:
-            raise FileNotFoundError("Pathway path:{ORG}{CODE} not saved in local storage".format(ORG=org, CODE=code))
+
+        raise FileNotFoundError(
+            "Pathway path:{ORG}{CODE} not saved in local storage".format(ORG=org, CODE=code))
+
 
     @staticmethod
     def save(filename: str, data: str):
@@ -150,13 +189,15 @@ class KEGGDataStorage:
         :param data: str
         :return: str
         """
+
         KEGGDataStorage._check_env()
         path = os.path.join(KEGG_DATA, filename)
-        with open(path, "w") as f:
-            f.write(data)
-            f.close()
+        with open(path, "w") as f_obj:
+            f_obj.write(data)
+            f_obj.close()
         return path
 
+
     @staticmethod
     def save_dump(filename: str, data):
         """
@@ -165,11 +206,13 @@ class KEGGDataStorage:
         :param data: str
         :return: str
         """
+
         KEGGDataStorage._check_env()
         path = os.path.join(KEGG_DATA, filename)
         pickle.dump(data, open(path, "wb"))
         return path
 
+
     @staticmethod
     def load(filename: str):
         """
@@ -177,15 +220,17 @@ class KEGGDataStorage:
         :param filename: str
         :return: str
         """
+
         KEGGDataStorage._check_env()
         path = os.path.join(KEGG_DATA, filename)
         if not os.path.isfile(path):
             raise FileNotFoundError("File at path {PATH} does not exist".format(PATH=path))
-        with open(path, "r") as f:
-            data = f.read()
-            f.close()
+        with open(path, "r") as f_obj:
+            data = f_obj.read()
+            f_obj.close()
         return data
 
+
     @staticmethod
     def load_dump(filename: str):
         """
@@ -205,15 +250,15 @@ if __name__ == "__main__":
     logging.basicConfig(level=logging.DEBUG)
 
     # get all stored pathways files from folder
-    pathway_files = KEGGDataStorage.list_existing_pathways()
-    logging.debug("Found {N} kgml files in folder".format(N=len(pathway_files)))
+    PATHWAY_FILES = KEGGDataStorage.list_existing_pathways()
+    logging.debug("Found %d kgml files in folder", len(PATHWAY_FILES))
 
     # convert pathway file string to pathway ids
-    pathway_ids = [KEGGDataStorage.pathway_file_to_id(p) for p in pathway_files]
-    logging.debug(len(pathway_ids), "total pathway ids found.")
+    PATHWAY_IDS = [KEGGDataStorage.pathway_file_to_id(p) for p in PATHWAY_FILES]
+    logging.debug("%d total pathway ids found.", len(PATHWAY_IDS))
 
     # load organism list
-    logging.debug(len(KEGGDataStorage.get_organism_list().keys()), "organisms found.")
+    logging.debug("%d organisms found.", len(KEGGDataStorage.get_organism_list().keys()))
 
     # check if pathway file exists
     logging.debug(KEGGDataStorage.pathway_file_exist(org="mmu", code="00010"))
@@ -223,4 +268,3 @@ if __name__ == "__main__":
 
     # get name of organism from code
     logging.debug(KEGGDataStorage.get_organism_name(org_code="mmu"))
-
